/*!
@ng-dynamic-forms/ui-foundation 5.4.7 2018-03-16 23:20 UTC
Copyright (c) 2016-2017, Udo Schöfer http://www.udos86.de

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
import { ChangeDetectorRef, Component, ContentChildren, EventEmitter, Input, Output, ViewChildren, NgModule } from '@angular/core';
import { ReactiveFormsModule } from '@angular/forms';
import { DynamicFormControlComponent, DynamicFormLayoutService, DynamicFormValidationService, DynamicTemplateDirective, DYNAMIC_FORM_CONTROL_TYPE_ARRAY, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP, DYNAMIC_FORM_CONTROL_TYPE_GROUP, DYNAMIC_FORM_CONTROL_TYPE_INPUT, DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP, DYNAMIC_FORM_CONTROL_TYPE_SELECT, DYNAMIC_FORM_CONTROL_TYPE_SWITCH, DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA, DynamicFormComponent, DynamicFormService, DynamicFormsCoreModule } from '@ng-dynamic-forms/core';
import { CommonModule } from '@angular/common';
import { TextMaskModule } from 'angular2-text-mask';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DynamicFoundationFormControlComponent extends DynamicFormControlComponent {
    /**
     * @param {?} changeDetectorRef
     * @param {?} layoutService
     * @param {?} validationService
     */
    constructor(changeDetectorRef, layoutService, validationService) {
        super(changeDetectorRef, layoutService, validationService);
        this.changeDetectorRef = changeDetectorRef;
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.bindId = true;
        this.context = null;
        this.hasErrorMessaging = false;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes["model"]) {
            this.type = DynamicFoundationFormControlComponent.getFormControlType(this.model);
        }
    }
    /**
     * @param {?} model
     * @return {?}
     */
    static getFormControlType(model) {
        switch (model.type) {
            case DYNAMIC_FORM_CONTROL_TYPE_ARRAY:
                return 1 /* Array */;
            case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX:
                return 2 /* Checkbox */;
            case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP:
            case DYNAMIC_FORM_CONTROL_TYPE_GROUP:
                return 3 /* Group */;
            case DYNAMIC_FORM_CONTROL_TYPE_INPUT:
                return 4 /* Input */;
            case DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP:
                return 5 /* RadioGroup */;
            case DYNAMIC_FORM_CONTROL_TYPE_SELECT:
                return 6 /* Select */;
            case DYNAMIC_FORM_CONTROL_TYPE_SWITCH:
                return 7 /* Switch */;
            case DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA:
                return 8 /* TextArea */;
            default:
                return null;
        }
    }
}
DynamicFoundationFormControlComponent.decorators = [
    { type: Component, args: [{
                selector: "dynamic-foundation-form-control,dynamic-form-foundation-sites-control",
                template: "<div [formGroup]=\"group\" [ngClass]=\"[getClass('element', 'container'), getClass('grid', 'container')]\"><div *ngIf=\"type !== 2 && model.label\" [ngClass]=\"getClass('grid', 'label')\"><label [class.is-invalid-label]=\"showErrorMessages\" [for]=\"model.id\" [innerHTML]=\"model.label\" [ngClass]=\"getClass('element', 'label')\"></label></div><ng-container *ngTemplateOutlet=\"templates[0]?.templateRef; context: model\"></ng-container><div [ngClass]=\"getClass('grid', 'control')\"><ng-container [ngSwitch]=\"type\"><div *ngSwitchCase=\"1\" [dynamicId]=\"bindId && model.id\" [formArrayName]=\"model.id\" [ngClass]=\"getClass('element', 'control')\"><div *ngFor=\"let groupModel of model.groups; let idx = index\" role=\"group\" [formGroupName]=\"idx\" [ngClass]=\"[getClass('element', 'group'), getClass('grid', 'group')]\"><dynamic-foundation-form-control *ngFor=\"let _model of groupModel.group\" [bindId]=\"false\" [context]=\"groupModel\" [group]=\"control.at(idx)\" [hasErrorMessaging]=\"_model.hasErrorMessages\" [hidden]=\"_model.hidden\" [layout]=\"layout\" [model]=\"_model\" [templates]=\"templateList\" [ngClass]=\"[getClass('element', 'host', _model), getClass('grid', 'host', _model)]\" (dfBlur)=\"onBlur($event)\" (dfChange)=\"onValueChange($event)\" (dfFocus)=\"onFocus($event)\"></dynamic-foundation-form-control><ng-container *ngTemplateOutlet=\"templates[2]?.templateRef; context: groupModel\"></ng-container></div></div><label *ngSwitchCase=\"2\"><input type=\"checkbox\" [checked]=\"model.checked\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [indeterminate]=\"model.indeterminate\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [required]=\"model.required\" [tabindex]=\"model.tabIndex\" [value]=\"model.value\" (blur)=\"onBlur($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocus($event)\"><span [ngClass]=\"[getClass('element', 'label'), getClass('grid', 'label')]\" [innerHTML]=\"model.label\"></span></label><fieldset *ngSwitchCase=\"3\" [dynamicId]=\"bindId && model.id\" [formGroupName]=\"model.id\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\"><legend *ngIf=\"model.legend\">{{model.legend}}</legend><dynamic-foundation-form-control *ngFor=\"let _model of model.group\" [group]=\"control\" [hasErrorMessaging]=\"_model.hasErrorMessages\" [hidden]=\"_model.hidden\" [layout]=\"layout\" [model]=\"_model\" [templates]=\"templateList\" [ngClass]=\"[getClass('element', 'host', _model), getClass('grid', 'host', _model)]\" (dfBlur)=\"onBlur($event)\" (dfChange)=\"onValueChange($event)\" (dfFocus)=\"onFocus($event)\"></dynamic-foundation-form-control></fieldset><div *ngSwitchCase=\"4\" class=\"input-group\"><span *ngIf=\"model.prefix\" class=\"input-group-label\" [innerHTML]=\"model.prefix\"></span> <input class=\"input-group-field\" [attr.accept]=\"model.accept\" [attr.list]=\"model.listId\" [attr.max]=\"model.max\" [attr.min]=\"model.min\" [attr.multiple]=\"model.multiple\" [attr.step]=\"model.step\" [autocomplete]=\"model.autoComplete\" [autofocus]=\"model.autoFocus\" [class.is-invalid-input]=\"showErrorMessages\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [maxlength]=\"model.maxLength\" [minlength]=\"model.minLength\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [pattern]=\"model.pattern\" [placeholder]=\"model.placeholder\" [readonly]=\"model.readOnly\" [required]=\"model.required\" [spellcheck]=\"model.spellCheck\" [tabindex]=\"model.tabIndex\" [textMask]=\"{mask: (model.mask || false), showMask: model.mask && !(model.placeholder)}\" [type]=\"model.inputType\" (blur)=\"onBlur($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocus($event)\"> <span *ngIf=\"model.suffix\" class=\"input-group-label\" [innerHTML]=\"model.suffix\"></span><datalist *ngIf=\"hasList\" [id]=\"model.listId\"><option *ngFor=\"let option of model.list\" [value]=\"option\"></option></datalist></div><fieldset *ngSwitchCase=\"5\" role=\"radiogroup\" [dynamicId]=\"bindId && model.id\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [tabindex]=\"model.tabIndex\" (change)=\"onValueChange($event)\"><legend *ngIf=\"model.legend\" [innerHTML]=\"model.legend\"></legend><label *ngFor=\"let option of model.options$ | async\" [ngClass]=\"getClass('element', 'option')\"><input type=\"radio\" [formControlName]=\"model.id\" [name]=\"model.name\" [value]=\"option.value\" (blur)=\"onBlur($event)\" (focus)=\"onFocus($event)\"><span [innerHTML]=\"option.label\"></span></label></fieldset><select *ngSwitchCase=\"6\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [required]=\"model.required\" [tabindex]=\"model.tabIndex\" (blur)=\"onBlur($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocus($event)\"><option *ngFor=\"let option of model.options$ | async\" [disabled]=\"option.disabled\" [ngValue]=\"option.value\">{{ option.label }}</option></select><div *ngSwitchCase=\"7\" class=\"switch\" [ngClass]=\"getClass('element', 'control')\"><input type=\"checkbox\" class=\"switch-input\" [checked]=\"model.checked\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [name]=\"model.name\" [required]=\"model.required\" [tabindex]=\"model.tabIndex\" [value]=\"model.value\" (blur)=\"onBlur($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocus($event)\"> <label class=\"switch-paddle\" [for]=\"model.id\"><span class=\"switch-active\" aria-hidden=\"true\">{{ model.onLabel }}</span> <span class=\"switch-inactive\" aria-hidden=\"true\">{{ model.offLabel }}</span></label></div><textarea *ngSwitchCase=\"8\" [class.is-invalid-input]=\"showErrorMessages\" [cols]=\"model.cols\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [maxlength]=\"model.maxLength\" [minlength]=\"model.minLength\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [placeholder]=\"model.placeholder\" [readonly]=\"model.readOnly\" [required]=\"model.required\" [rows]=\"model.rows\" [spellcheck]=\"model.spellCheck\" [tabindex]=\"model.tabIndex\" [wrap]=\"model.wrap\" (blur)=\"onBlur($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocus($event)\"></textarea></ng-container><p *ngIf=\"showHint\" class=\"help-text\" [ngClass]=\"getClass('element', 'hint')\" [innerHTML]=\"model.hint\"></p></div><ul *ngIf=\"showErrorMessages\" [ngClass]=\"[getClass('element', 'errors'), getClass('grid', 'errors')]\"><li *ngFor=\"let message of errorMessages\" class=\"form-error is-visible\">{{ message }}</li></ul><ng-container *ngTemplateOutlet=\"templates[1]?.templateRef; context: model\"></ng-container><ng-content></ng-content></div>"
            },] },
];
/** @nocollapse */
DynamicFoundationFormControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef, },
    { type: DynamicFormLayoutService, },
    { type: DynamicFormValidationService, },
];
DynamicFoundationFormControlComponent.propDecorators = {
    "contentTemplateList": [{ type: ContentChildren, args: [DynamicTemplateDirective,] },],
    "inputTemplateList": [{ type: Input, args: ["templates",] },],
    "bindId": [{ type: Input },],
    "context": [{ type: Input },],
    "group": [{ type: Input },],
    "hasErrorMessaging": [{ type: Input },],
    "layout": [{ type: Input },],
    "model": [{ type: Input },],
    "blur": [{ type: Output, args: ["dfBlur",] },],
    "change": [{ type: Output, args: ["dfChange",] },],
    "focus": [{ type: Output, args: ["dfFocus",] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DynamicFoundationFormComponent extends DynamicFormComponent {
    /**
     * @param {?} formService
     * @param {?} layoutService
     */
    constructor(formService, layoutService) {
        super(formService, layoutService);
        this.formService = formService;
        this.layoutService = layoutService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
}
DynamicFoundationFormComponent.decorators = [
    { type: Component, args: [{
                selector: "dynamic-foundation-form",
                template: "<dynamic-foundation-form-control *ngFor=\"let model of formModel; trackBy: trackByFn\" [group]=\"formGroup\" [hasErrorMessaging]=\"model.hasErrorMessages\" [hidden]=\"model.hidden\" [layout]=\"formLayout\" [model]=\"model\" [ngClass]=\"[getClass(model,'element','host'), getClass(model,'grid','host')]\" [templates]=\"templates\" (dfBlur)=\"onEvent($event, 'blur')\" (dfChange)=\"onEvent($event, 'change')\" (dfFocus)=\"onEvent($event, 'focus')\"></dynamic-foundation-form-control>"
            },] },
];
/** @nocollapse */
DynamicFoundationFormComponent.ctorParameters = () => [
    { type: DynamicFormService, },
    { type: DynamicFormLayoutService, },
];
DynamicFoundationFormComponent.propDecorators = {
    "formGroup": [{ type: Input, args: ["group",] },],
    "formModel": [{ type: Input, args: ["model",] },],
    "formLayout": [{ type: Input, args: ["layout",] },],
    "blur": [{ type: Output, args: ["dfBlur",] },],
    "change": [{ type: Output, args: ["dfChange",] },],
    "focus": [{ type: Output, args: ["dfFocus",] },],
    "templates": [{ type: ContentChildren, args: [DynamicTemplateDirective,] },],
    "components": [{ type: ViewChildren, args: [DynamicFoundationFormControlComponent,] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DynamicFormsFoundationUIModule {
}
DynamicFormsFoundationUIModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ReactiveFormsModule,
                    TextMaskModule,
                    DynamicFormsCoreModule
                ],
                declarations: [
                    DynamicFoundationFormControlComponent,
                    DynamicFoundationFormComponent
                ],
                exports: [
                    DynamicFormsCoreModule,
                    DynamicFoundationFormControlComponent,
                    DynamicFoundationFormComponent
                ]
            },] },
];
/** @nocollapse */
DynamicFormsFoundationUIModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

export { DynamicFoundationFormComponent, DynamicFoundationFormControlComponent, DynamicFormsFoundationUIModule };
//# sourceMappingURL=ui-foundation.js.map
